@@ -31,7 +31,6 @@
 #include <midgard/midgard_connection.h>
 #include <midgard/midgard_metadata.h>
 #include <midgard/midgard_object.h>
-#include <midgard/midgard_object_class.h>
 #include <midgard/midgard_quota.h>
 #include <midgard/midgard_reflection_property.h>
 #include <midgard/midgard_collector.h>
@@ -50,6 +49,19 @@
 #include <midgard/midgard_transaction.h>
 #include <midgard/midgard_view.h>
 #include <midgard/midgard_key_config_common.h>
+#include <midgard/midgard_query_constraint_simple.h>
+#include <midgard/midgard_query_holder.h>
+#include <midgard/midgard_query_value.h>
+#include <midgard/midgard_query_property.h>
+#include <midgard/midgard_query_executor.h>
+#include <midgard/midgard_query_select.h>
+#include <midgard/midgard_query_storage.h>
+#include <midgard/midgard_query_constraint.h>
+#include <midgard/midgard_query_constraint_group.h>
+#include <midgard/midgard_reflector_object.h>
+#include <midgard/midgard_reflector_property.h>
+#include <midgard/midgard_schema_object_factory.h>
+#include <midgard/midgard_schema_object_tree.h>
 
 #endif /* _MIDGARD_API_H_ */
 
