@@ -772,13 +772,13 @@ gboolean midgard_config_save_file(MidgardConfig *self,
 	gboolean saved = g_file_set_contents(cnfpath, content, length, &kf_error);
 
 	g_free (content);
-	g_free (cnfpath);
 
 	if (!saved) {
 
 		if (kf_error)
 			g_propagate_error (error, kf_error);
-	
+
+		g_free (cnfpath);
 		return FALSE;
 	}
 
@@ -788,6 +788,8 @@ gboolean midgard_config_save_file(MidgardConfig *self,
 	g_chmod(cnfpath, 0600);
 #endif /* G_OS_WIN32 */
 
+	g_free (cnfpath);
+
 	return TRUE;
 }
 
@@ -1118,6 +1120,10 @@ __midgard_config_struct_free (MidgardConfig *self)
 		g_free (self->vardir);
 	self->vardir = NULL;
 
+	if (self->viewsdir)
+		g_free (self->viewsdir);
+	self->viewsdir = NULL;
+
 	if (self->dbtype)
 		g_free (self->dbtype);
 	self->dbtype = NULL;
