@@ -548,6 +548,7 @@ midgard_core_query_get_dbobject_model (MidgardConnection *mgd, MidgardDBObjectCl
 		g_free (debug_query);
 	}
 
+	g_free (col_types);
 	g_object_unref (params);
 	g_object_unref (stmt);
 
@@ -641,6 +642,7 @@ midgard_core_query_get_dbobject_model (MidgardConnection *mgd, MidgardDBObjectCl
 				g_object_get (object, pname, &mt, NULL);		\
 				pstr = midgard_timestamp_get_string (mt);		\
 				gda_set_set_holder_value (params, NULL, col_name, pstr);\
+				midgard_timestamp_free (mt);				\
 				g_free (pstr);						\
 			}								\
 		break;									\
@@ -2475,7 +2477,7 @@ midgard_core_query_binary_stringify (GValue *src_value)
 {
 	g_return_val_if_fail (src_value != NULL, NULL);
 
-	const GdaBinary *binary;
+	const GdaBinary *binary = NULL;
 	if (G_VALUE_TYPE (src_value) == GDA_TYPE_BLOB) {
 		const GdaBlob *blob = gda_value_get_blob (src_value);
 		binary = &blob->data;
