@@ -71,6 +71,8 @@ _add_fields_to_select_statement (MidgardDBObjectClass *klass, GdaConnection *cnc
 		select_field->expr = expr;
 	}	
 
+	g_free (pspecs);
+
 	if (!klass->dbpriv->has_metadata)
 		return;
 
@@ -497,6 +499,14 @@ midgard_dbobject_constructor (GType type,
 	return G_OBJECT(object);
 }
 
+static void __weak_ref_notify (gpointer data, GObject *object)
+{
+	if (data != NULL && G_IS_OBJECT (data)) {	
+		MidgardDBObject *dbobject = MIDGARD_DBOBJECT (data);
+		MGD_OBJECT_CNC (dbobject) = NULL;
+	}
+}
+
 static void 
 midgard_dbobject_dispose (GObject *object)
 {
@@ -506,15 +516,16 @@ midgard_dbobject_dispose (GObject *object)
 
 	self->dbpriv->row = -1;
 
-	/* Do not nullify metadata object, we might be in the middle of refcount decreasing */
 	MidgardMetadata *metadata = MGD_DBOBJECT_METADATA (self);
-	if (metadata && G_IS_OBJECT (metadata)) 
+	if (metadata && G_IS_OBJECT (metadata)) {
 		g_object_unref (metadata);
+		MGD_DBOBJECT_METADATA (self) = NULL;
+	}
 
-	/* Drop reference to MidgardConnection */
+	/* Nullify connection's pointer. */
 	MidgardConnection *mgd = MIDGARD_DBOBJECT (self)->dbpriv->mgd;
-	if (mgd != NULL && G_IS_OBJECT (mgd)) {	
-		g_object_unref (MIDGARD_DBOBJECT (self)->dbpriv->mgd);
+	if (mgd != NULL && G_IS_OBJECT (mgd)) {
+		g_object_weak_unref (G_OBJECT(self->dbpriv->mgd), __weak_ref_notify, self);	
 		MIDGARD_DBOBJECT (self)->dbpriv->mgd = NULL;
 	}
 
@@ -573,11 +584,17 @@ __midgard_dbobject_set_property (GObject *object, guint property_id,
 			if (!G_VALUE_HOLDS_OBJECT (value)) 
 				return;
 
-			if (!MIDGARD_IS_CONNECTION (g_value_get_object (value)))
+			mgd = g_value_get_object (value);
+
+			if (!MIDGARD_IS_CONNECTION (mgd))
 				return;
 	
-			/* Add new reference to MidgardConnection object */
-			MIDGARD_DBOBJECT (object)->dbpriv->mgd = g_value_dup_object (value);
+			MIDGARD_DBOBJECT (object)->dbpriv->mgd = MIDGARD_CONNECTION (mgd);
+			/* Add weak reference callback to connection. 
+			 * Instead of keeping connection's alive (implicitly) we create sentinel 
+			 * which guarantees connection's pointer to be null if connection is destroyed. */
+			g_object_weak_ref (mgd, __weak_ref_notify, object);
+
 			break;
 
   		default:
