@@ -65,7 +65,11 @@ _action_create_callback (MidgardObject *object, gpointer ud)
 	g_value_unset (&rev_val);
 
 	/* set default values */
+	if (mdata->priv->locker)
+		g_free (mdata->priv->locker);
 	mdata->priv->locker = g_strdup ("");
+	if (mdata->priv->approver)
+		g_free (mdata->priv->approver);
 	mdata->priv->approver = g_strdup ("");
 
 	if (!mdata->priv->authors)
@@ -99,10 +103,6 @@ _action_update_callback (MidgardObject *object, gpointer ud)
 	midgard_core_metadata_set_revised (mdata, (const GValue *)&tval);	
 	g_value_unset (&tval);
 
-	GValue _val = {0, };
-	g_value_init (&_val, MIDGARD_TYPE_TIMESTAMP);
-	g_object_get_property (G_OBJECT (mdata), "revised", &_val);
-
 	/* set revision */
 	midgard_core_metadata_increase_revision (mdata);
 }
@@ -567,6 +567,8 @@ _metadata_instance_init(GTypeInstance *instance, gpointer g_class)
 
 	self->priv->approve_is_set = FALSE;
 	self->priv->is_approved = FALSE;
+
+	self->priv->object = NULL;
 }
 
 static void 
@@ -592,7 +594,13 @@ _metadata_object_finalize(GObject *object)
 	g_free(self->priv->published);
 	g_free(self->priv->exported);
 	g_free(self->priv->imported);
-	
+
+	/* Set parent's object metadata to NULL, if metadata unref has been 
+	 * invoked on metadata directly */
+	if (self->priv->object 
+			&& G_IS_OBJECT (self->priv->object))
+	       MGD_DBOBJECT_METADATA (self->priv->object) = NULL;	
+
 	g_free(self->priv);
 
 	__parent_class->finalize (object);
