@@ -251,7 +251,6 @@ __midgard_user_get (MidgardConnection *mgd, guint n_params, const GParameter *pa
 
 	if (rows > 1) {
 		
-		g_object_unref (model);
 		g_warning ("midgard_user storage inconsistency. Found %d records. Expected one.", rows);
 		MIDGARD_ERRNO_SET (mgd, MGD_ERR_INTERNAL);
 	}
@@ -266,6 +265,7 @@ __midgard_user_get (MidgardConnection *mgd, guint n_params, const GParameter *pa
 	MidgardUser *self = g_object_new (MIDGARD_TYPE_USER, "connection", mgd, NULL);
 
 	MIDGARD_DBOBJECT_CLASS (klass)->dbpriv->__set_from_sql (MIDGARD_DBOBJECT (self), model, 0);
+	g_object_unref (model);
 
 	return self;
 }
@@ -364,8 +364,7 @@ __midgard_user_query (MidgardConnection *mgd, guint n_params, const GParameter *
 
 	for (i = 0; i < rows; i++) {
 	
-		users[i] = g_object_new (MIDGARD_TYPE_USER, NULL);
-		MIDGARD_DBOBJECT (users[i])->dbpriv->mgd = mgd;
+		users[i] = g_object_new (MIDGARD_TYPE_USER, "connection", mgd, NULL);
 		MIDGARD_DBOBJECT_CLASS (klass)->dbpriv->__set_from_sql (MIDGARD_DBOBJECT (users[i]), model, i);
 	}
 
@@ -478,6 +477,7 @@ __midgard_user_create (MidgardUser *self)
 
 	if (user) {
 		
+		g_object_unref (user);
 		MIDGARD_ERRNO_SET (mgd, MGD_ERR_DUPLICATE);
 		return FALSE;
 	}
@@ -719,6 +719,8 @@ __midgard_user_delete (MidgardUser *self)
  * Which means, #MidgardObject must be fetched from database.
  * Either with midgard_user_get() or with midgard_user_query().
  *
+ * This method silently returns with success when given user is already logged in.
+ *
  * Cases to return %FALSE:
  * <itemizedlist>
  * <listitem><para>
@@ -750,6 +752,10 @@ __midgard_user_login (MidgardUser *self)
 
 	MIDGARD_ERRNO_SET(mgd, MGD_ERR_OK);
 
+	/* Check if given user instance is already logged in */
+	if (mgd->priv->user && mgd->priv->user == self)
+		return TRUE;
+
 	const gchar *guid = MGD_OBJECT_GUID(self);
 	if (!guid
 		|| (guid && *guid == '\0')
@@ -978,14 +984,17 @@ static void __set_from_sql(MidgardDBObject *object,
 	if (value && G_VALUE_HOLDS_STRING (value))
 		self->priv->password = g_value_dup_string (value);
 	else 
-		g_warning ("Invalid value type for user's password. Expected string, got %s", G_VALUE_TYPE_NAME (value));
+		g_warning ("Invalid value type for user's password. Expected string, got %s", value ? G_VALUE_TYPE_NAME (value) : "NULL");
 
 	/* PERSON GUID */
 	value = midgard_data_model_get_value_at_col_name (model, "person", row);
-	if (value && G_IS_VALUE (value) && G_VALUE_HOLDS_STRING (value))
+	if (value && G_IS_VALUE (value) && G_VALUE_HOLDS_STRING (value)) {
+		g_free (self->priv->person_guid);
 		self->priv->person_guid = g_value_dup_string (value);
-	else 
-		g_warning ("Invalid value type for user's person guid. Expected string, got %s", G_VALUE_TYPE_NAME (value));
+	
+	} else {
+		g_warning ("Invalid value type for user's person guid. Expected string, got %s", value ? G_VALUE_TYPE_NAME (value) : "NULL");
+	}
 
 	/* ACTIVE */
 	value = midgard_data_model_get_value_at_col_name (model, "active", row);
