@@ -50,6 +50,7 @@ struct _MgdSchemaPropertyAttr{
 	gboolean is_unique;
 	gchar *description;
 	GHashTable *user_values;
+	MgdSchemaPropertyAttr *derived;
 };
 
 struct _MgdSchemaTypeAttr {
@@ -64,6 +65,7 @@ struct _MgdSchemaTypeAttr {
 	GSList *_properties_list;
 	const gchar *tables;
 	const gchar *table;
+	const gchar *view_table; /* Valid, only in case of MidgardView derived class */
 	const gchar *parent;
 	const gchar *primary;
 	const gchar *property_up;
